# Generated by Django 4.0.7 on 2022-09-16 09:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("service", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="translation",
            name="key",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.RESTRICT,
                related_name="translation_keys",
                to="service.translationkey",
            ),
        ),
        migrations.AlterField(
            model_name="translation",
            name="language",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.RESTRICT, related_name="translations", to="service.language"
            ),
        ),
    ]
