# Generated by Django 4.0.8 on 2022-11-23 15:26

import django.contrib.postgres.indexes
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("service", "0002_alter_translation_key_alter_translation_language"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="translationkey",
            index=django.contrib.postgres.indexes.GinIndex(
                fastupdate=False, fields=["occurrences", "views"], name="occ_views_gin"
            ),
        ),
    ]
